@@ -3,6 +3,8 @@ import hackingtools as ht
 
 from PIL import Image
 from PyPDF2 import PdfFileReader, PdfFileWriter
+from pdfrw import PdfReader, PdfWriter 
+# import mutagen
 
 import os
 
@@ -45,3 +47,26 @@ class StartModule():
 			Logger.printMessage(message='{methodName}'.format(methodName='exception'), description=e, debug_module=True)
 			return e
 		return -1
+	
+	def set_pdf_author(self, pdf_file, author):
+		try:
+			trailer = PdfReader(pdf_file)    
+			trailer.Info.Creator = author
+			new_pdf = 'edited-{f}'.format(f=os.path.split(pdf_file)[1])
+			new_file = os.path.join( os.path.split(pdf_file)[0], new_pdf)
+			PdfWriter(new_file, trailer=trailer).write()
+			return new_file
+		except Exception as e:
+			Logger.printMessage(str(e), is_error=True)
+
+	# def get_audio_video_exif(self, filename):
+	# 	Logger.printMessage(message='{methodName}'.format(methodName='get_audio_video_exif'), description=filename, debug_module=True)
+	# 	try:
+	# 		my_file = mutagen.File(filename)
+	# 		img_file.verify()
+	# 		info = img_file._getexif()
+	# 		return info
+	# 	except Exception as e:
+	# 		Logger.printMessage(message='{methodName}'.format(methodName='exception'), description=e, debug_module=True)
+	# 		return e
+	# 	return -1
